# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from slack_beta_ti.models.default_success_template import DefaultSuccessTemplate

from slack_beta_ti.api_client import ApiClient, RequestSerialized
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.rest import RESTResponseType


class CallsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def calls_add(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        external_unique_id: Annotated[StrictStr, Field(description="An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service.")],
        join_url: Annotated[StrictStr, Field(description="The URL required for a client to join the Call.")],
        external_display_id: Annotated[Optional[StrictStr], Field(description="An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        date_start: Annotated[Optional[StrictInt], Field(description="Call start time in UTC UNIX timestamp format")] = None,
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        created_by: Annotated[Optional[StrictStr], Field(description="The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.")] = None,
        users: Annotated[Optional[StrictStr], Field(description="The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_add

        Registers a new Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param external_unique_id: An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service. (required)
        :type external_unique_id: str
        :param join_url: The URL required for a client to join the Call. (required)
        :type join_url: str
        :param external_display_id: An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.
        :type external_display_id: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :param date_start: Call start time in UTC UNIX timestamp format
        :type date_start: int
        :param title: The name of the Call.
        :type title: str
        :param created_by: The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.
        :type created_by: str
        :param users: The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_add_serialize(
            token=token,
            external_unique_id=external_unique_id,
            join_url=join_url,
            external_display_id=external_display_id,
            desktop_app_join_url=desktop_app_join_url,
            date_start=date_start,
            title=title,
            created_by=created_by,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_add_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        external_unique_id: Annotated[StrictStr, Field(description="An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service.")],
        join_url: Annotated[StrictStr, Field(description="The URL required for a client to join the Call.")],
        external_display_id: Annotated[Optional[StrictStr], Field(description="An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        date_start: Annotated[Optional[StrictInt], Field(description="Call start time in UTC UNIX timestamp format")] = None,
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        created_by: Annotated[Optional[StrictStr], Field(description="The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.")] = None,
        users: Annotated[Optional[StrictStr], Field(description="The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_add

        Registers a new Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param external_unique_id: An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service. (required)
        :type external_unique_id: str
        :param join_url: The URL required for a client to join the Call. (required)
        :type join_url: str
        :param external_display_id: An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.
        :type external_display_id: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :param date_start: Call start time in UTC UNIX timestamp format
        :type date_start: int
        :param title: The name of the Call.
        :type title: str
        :param created_by: The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.
        :type created_by: str
        :param users: The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_add_serialize(
            token=token,
            external_unique_id=external_unique_id,
            join_url=join_url,
            external_display_id=external_display_id,
            desktop_app_join_url=desktop_app_join_url,
            date_start=date_start,
            title=title,
            created_by=created_by,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_add_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        external_unique_id: Annotated[StrictStr, Field(description="An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service.")],
        join_url: Annotated[StrictStr, Field(description="The URL required for a client to join the Call.")],
        external_display_id: Annotated[Optional[StrictStr], Field(description="An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        date_start: Annotated[Optional[StrictInt], Field(description="Call start time in UTC UNIX timestamp format")] = None,
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        created_by: Annotated[Optional[StrictStr], Field(description="The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.")] = None,
        users: Annotated[Optional[StrictStr], Field(description="The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_add

        Registers a new Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param external_unique_id: An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service. (required)
        :type external_unique_id: str
        :param join_url: The URL required for a client to join the Call. (required)
        :type join_url: str
        :param external_display_id: An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.
        :type external_display_id: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :param date_start: Call start time in UTC UNIX timestamp format
        :type date_start: int
        :param title: The name of the Call.
        :type title: str
        :param created_by: The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.
        :type created_by: str
        :param users: The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_add_serialize(
            token=token,
            external_unique_id=external_unique_id,
            join_url=join_url,
            external_display_id=external_display_id,
            desktop_app_join_url=desktop_app_join_url,
            date_start=date_start,
            title=title,
            created_by=created_by,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_add_serialize(
        self,
        token,
        external_unique_id,
        join_url,
        external_display_id,
        desktop_app_join_url,
        date_start,
        title,
        created_by,
        users,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if external_unique_id is not None:
            _form_params.append(('external_unique_id', external_unique_id))
        if external_display_id is not None:
            _form_params.append(('external_display_id', external_display_id))
        if join_url is not None:
            _form_params.append(('join_url', join_url))
        if desktop_app_join_url is not None:
            _form_params.append(('desktop_app_join_url', desktop_app_join_url))
        if date_start is not None:
            _form_params.append(('date_start', date_start))
        if title is not None:
            _form_params.append(('title', title))
        if created_by is not None:
            _form_params.append(('created_by', created_by))
        if users is not None:
            _form_params.append(('users', users))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.add',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_end(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned when registering the call using the [`calls.add`](/methods/calls.add) method.")],
        duration: Annotated[Optional[StrictInt], Field(description="Call duration in seconds")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_end

        Ends a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned when registering the call using the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param duration: Call duration in seconds
        :type duration: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_end_serialize(
            token=token,
            id=id,
            duration=duration,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_end_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned when registering the call using the [`calls.add`](/methods/calls.add) method.")],
        duration: Annotated[Optional[StrictInt], Field(description="Call duration in seconds")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_end

        Ends a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned when registering the call using the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param duration: Call duration in seconds
        :type duration: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_end_serialize(
            token=token,
            id=id,
            duration=duration,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_end_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned when registering the call using the [`calls.add`](/methods/calls.add) method.")],
        duration: Annotated[Optional[StrictInt], Field(description="Call duration in seconds")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_end

        Ends a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned when registering the call using the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param duration: Call duration in seconds
        :type duration: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_end_serialize(
            token=token,
            id=id,
            duration=duration,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_end_serialize(
        self,
        token,
        id,
        duration,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if id is not None:
            _form_params.append(('id', id))
        if duration is not None:
            _form_params.append(('duration', duration))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.end',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:read`")],
        id: Annotated[StrictStr, Field(description="`id` of the Call returned by the [`calls.add`](/methods/calls.add) method.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_info

        Returns information about a Call.

        :param token: Authentication token. Requires scope: `calls:read` (required)
        :type token: str
        :param id: `id` of the Call returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_info_serialize(
            token=token,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_info_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:read`")],
        id: Annotated[StrictStr, Field(description="`id` of the Call returned by the [`calls.add`](/methods/calls.add) method.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_info

        Returns information about a Call.

        :param token: Authentication token. Requires scope: `calls:read` (required)
        :type token: str
        :param id: `id` of the Call returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_info_serialize(
            token=token,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_info_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:read`")],
        id: Annotated[StrictStr, Field(description="`id` of the Call returned by the [`calls.add`](/methods/calls.add) method.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_info

        Returns information about a Call.

        :param token: Authentication token. Requires scope: `calls:read` (required)
        :type token: str
        :param id: `id` of the Call returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_info_serialize(
            token=token,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_info_serialize(
        self,
        token,
        id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if id is not None:
            
            _query_params.append(('id', id))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/calls.info',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_participants_add(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_participants_add

        Registers new participants added to a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_add_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_participants_add_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_participants_add

        Registers new participants added to a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_add_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_participants_add_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_participants_add

        Registers new participants added to a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_add_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_participants_add_serialize(
        self,
        token,
        id,
        users,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if id is not None:
            _form_params.append(('id', id))
        if users is not None:
            _form_params.append(('users', users))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.participants.add',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_participants_remove(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_participants_remove

        Registers participants removed from a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_remove_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_participants_remove_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_participants_remove

        Registers participants removed from a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_remove_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_participants_remove_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_participants_remove

        Registers participants removed from a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_remove_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_participants_remove_serialize(
        self,
        token,
        id,
        users,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if id is not None:
            _form_params.append(('id', id))
        if users is not None:
            _form_params.append(('users', users))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.participants.remove',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_update(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        join_url: Annotated[Optional[StrictStr], Field(description="The URL required for a client to join the Call.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_update

        Updates information about a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param title: The name of the Call.
        :type title: str
        :param join_url: The URL required for a client to join the Call.
        :type join_url: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_update_serialize(
            token=token,
            id=id,
            title=title,
            join_url=join_url,
            desktop_app_join_url=desktop_app_join_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_update_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        join_url: Annotated[Optional[StrictStr], Field(description="The URL required for a client to join the Call.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_update

        Updates information about a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param title: The name of the Call.
        :type title: str
        :param join_url: The URL required for a client to join the Call.
        :type join_url: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_update_serialize(
            token=token,
            id=id,
            title=title,
            join_url=join_url,
            desktop_app_join_url=desktop_app_join_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_update_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        join_url: Annotated[Optional[StrictStr], Field(description="The URL required for a client to join the Call.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_update

        Updates information about a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param title: The name of the Call.
        :type title: str
        :param join_url: The URL required for a client to join the Call.
        :type join_url: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_update_serialize(
            token=token,
            id=id,
            title=title,
            join_url=join_url,
            desktop_app_join_url=desktop_app_join_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_update_serialize(
        self,
        token,
        id,
        title,
        join_url,
        desktop_app_join_url,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if id is not None:
            _form_params.append(('id', id))
        if title is not None:
            _form_params.append(('title', title))
        if join_url is not None:
            _form_params.append(('join_url', join_url))
        if desktop_app_join_url is not None:
            _form_params.append(('desktop_app_join_url', desktop_app_join_url))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.update',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class ObjsChannel(BaseModel):
    """
    ObjsChannel
    """ # noqa: E501
    accepted_user: Optional[Annotated[str, Field(strict=True)]] = None
    created: StrictInt
    creator: Annotated[str, Field(strict=True)]
    id: Annotated[str, Field(strict=True)]
    is_archived: Optional[StrictBool] = None
    is_channel: StrictBool
    is_frozen: Optional[StrictBool] = None
    is_general: Optional[StrictBool] = None
    is_member: Optional[StrictBool] = None
    is_moved: Optional[StrictInt] = None
    is_mpim: StrictBool
    is_non_threadable: Optional[StrictBool] = None
    is_org_shared: StrictBool
    is_pending_ext_shared: Optional[StrictBool] = None
    is_private: StrictBool
    is_read_only: Optional[StrictBool] = None
    is_shared: StrictBool
    is_thread_only: Optional[StrictBool] = None
    last_read: Optional[Annotated[str, Field(strict=True)]] = None
    latest: Optional[Dict[str, Any]] = None
    members: Annotated[List[Annotated[str, Field(strict=True)]], Field(min_length=0)]
    name: StrictStr
    name_normalized: StrictStr
    num_members: Optional[StrictInt] = None
    pending_shared: Optional[Annotated[List[Annotated[str, Field(strict=True)]], Field(min_length=0)]] = None
    previous_names: Optional[Annotated[List[StrictStr], Field(min_length=0)]] = None
    priority: Optional[Union[StrictFloat, StrictInt]] = None
    purpose: Dict[str, Any]
    topic: Dict[str, Any]
    unlinked: Optional[StrictInt] = None
    unread_count: Optional[StrictInt] = None
    unread_count_display: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["accepted_user", "created", "creator", "id", "is_archived", "is_channel", "is_frozen", "is_general", "is_member", "is_moved", "is_mpim", "is_non_threadable", "is_org_shared", "is_pending_ext_shared", "is_private", "is_read_only", "is_shared", "is_thread_only", "last_read", "latest", "members", "name", "name_normalized", "num_members", "pending_shared", "previous_names", "priority", "purpose", "topic", "unlinked", "unread_count", "unread_count_display"]

    @field_validator('accepted_user')
    def accepted_user_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    @field_validator('creator')
    def creator_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[C][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[C][A-Z0-9]{2,}$/")
        return value

    @field_validator('last_read')
    def last_read_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^\d{10}\.\d{6}$", value):
            raise ValueError(r"must validate the regular expression /^\d{10}\.\d{6}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ObjsChannel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ObjsChannel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accepted_user": obj.get("accepted_user"),
            "created": obj.get("created"),
            "creator": obj.get("creator"),
            "id": obj.get("id"),
            "is_archived": obj.get("is_archived"),
            "is_channel": obj.get("is_channel"),
            "is_frozen": obj.get("is_frozen"),
            "is_general": obj.get("is_general"),
            "is_member": obj.get("is_member"),
            "is_moved": obj.get("is_moved"),
            "is_mpim": obj.get("is_mpim"),
            "is_non_threadable": obj.get("is_non_threadable"),
            "is_org_shared": obj.get("is_org_shared"),
            "is_pending_ext_shared": obj.get("is_pending_ext_shared"),
            "is_private": obj.get("is_private"),
            "is_read_only": obj.get("is_read_only"),
            "is_shared": obj.get("is_shared"),
            "is_thread_only": obj.get("is_thread_only"),
            "last_read": obj.get("last_read"),
            "latest": obj.get("latest"),
            "members": obj.get("members"),
            "name": obj.get("name"),
            "name_normalized": obj.get("name_normalized"),
            "num_members": obj.get("num_members"),
            "pending_shared": obj.get("pending_shared"),
            "previous_names": obj.get("previous_names"),
            "priority": obj.get("priority"),
            "purpose": obj.get("purpose"),
            "topic": obj.get("topic"),
            "unlinked": obj.get("unlinked"),
            "unread_count": obj.get("unread_count"),
            "unread_count_display": obj.get("unread_count_display")
        })
        return _obj





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.chat_post_message_success_schema import ChatPostMessageSuccessSchema

class TestChatPostMessageSuccessSchema(unittest.TestCase):
    """ChatPostMessageSuccessSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatPostMessageSuccessSchema:
        """Test ChatPostMessageSuccessSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatPostMessageSuccessSchema`
        """
        model = ChatPostMessageSuccessSchema()
        if include_optional:
            return ChatPostMessageSuccessSchema(
                channel = 'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                message = slack_beta_ti.models.message_object.Message object(
                    attachments = [
                        None
                        ], 
                    blocks = [
                        None
                        ], 
                    bot_id = slack_beta_ti.models.bot_id.bot_id(), 
                    bot_profile = slack_beta_ti.models.bot_profile_object.Bot Profile Object(
                        app_id = 'A8', 
                        deleted = True, 
                        icons = slack_beta_ti.models.icons.icons(), 
                        id = 'B8Q6ZGCKEC0L3O4GI7XH', 
                        name = '', 
                        team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        updated = 56, ), 
                    client_msg_id = '', 
                    comment = slack_beta_ti.models.file_comment_object.File Comment Object(
                        comment = '', 
                        created = 56, 
                        id = 'Fc8Q6ZGCKEC0L3O4GI7XH', 
                        is_intro = True, 
                        is_starred = True, 
                        num_stars = 56, 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pinned_to = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        reactions = [
                            slack_beta_ti.models.reaction_object.Reaction object(
                                count = 56, 
                                name = '', 
                                users = [
                                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                    ], )
                            ], 
                        timestamp = 56, 
                        user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', ), 
                    display_as_bot = True, 
                    file = slack_beta_ti.models.file_object.file object(
                        channels = [
                            'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        comments_count = 56, 
                        created = 56, 
                        date_delete = 56, 
                        display_as_bot = True, 
                        editable = True, 
                        editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        external_id = '', 
                        external_type = '', 
                        external_url = '', 
                        filetype = '', 
                        groups = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        has_rich_preview = True, 
                        id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                        image_exif_rotation = 56, 
                        ims = [
                            'DQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        is_external = True, 
                        is_public = True, 
                        is_starred = True, 
                        is_tombstoned = True, 
                        last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        mimetype = '', 
                        mode = '', 
                        name = '', 
                        non_owner_editable = True, 
                        num_stars = 56, 
                        original_h = 56, 
                        original_w = 56, 
                        permalink = '', 
                        permalink_public = '', 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pretty_type = '', 
                        preview = '', 
                        public_url_shared = True, 
                        shares = slack_beta_ti.models.shares.shares(), 
                        size = 56, 
                        source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        state = '', 
                        thumb_1024 = '', 
                        thumb_1024_h = 56, 
                        thumb_1024_w = 56, 
                        thumb_160 = '', 
                        thumb_360 = '', 
                        thumb_360_h = 56, 
                        thumb_360_w = 56, 
                        thumb_480 = '', 
                        thumb_480_h = 56, 
                        thumb_480_w = 56, 
                        thumb_64 = '', 
                        thumb_720 = '', 
                        thumb_720_h = 56, 
                        thumb_720_w = 56, 
                        thumb_80 = '', 
                        thumb_800 = '', 
                        thumb_800_h = 56, 
                        thumb_800_w = 56, 
                        thumb_960 = '', 
                        thumb_960_h = 56, 
                        thumb_960_w = 56, 
                        thumb_tiny = '', 
                        timestamp = 56, 
                        title = '', 
                        updated = 56, 
                        url_private = '', 
                        url_private_download = '', 
                        user = '', 
                        user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        username = '', ), 
                    files = [
                        slack_beta_ti.models.file_object.file object(
                            comments_count = 56, 
                            created = 56, 
                            date_delete = 56, 
                            display_as_bot = True, 
                            editable = True, 
                            editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            external_id = '', 
                            external_type = '', 
                            external_url = '', 
                            filetype = '', 
                            has_rich_preview = True, 
                            id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                            image_exif_rotation = 56, 
                            is_external = True, 
                            is_public = True, 
                            is_starred = True, 
                            is_tombstoned = True, 
                            last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            mimetype = '', 
                            mode = '', 
                            name = '', 
                            non_owner_editable = True, 
                            num_stars = 56, 
                            original_h = 56, 
                            original_w = 56, 
                            permalink = '', 
                            permalink_public = '', 
                            pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                            pretty_type = '', 
                            preview = '', 
                            public_url_shared = True, 
                            shares = slack_beta_ti.models.shares.shares(), 
                            size = 56, 
                            source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            state = '', 
                            thumb_1024 = '', 
                            thumb_1024_h = 56, 
                            thumb_1024_w = 56, 
                            thumb_160 = '', 
                            thumb_360 = '', 
                            thumb_360_h = 56, 
                            thumb_360_w = 56, 
                            thumb_480 = '', 
                            thumb_480_h = 56, 
                            thumb_480_w = 56, 
                            thumb_64 = '', 
                            thumb_720 = '', 
                            thumb_720_h = 56, 
                            thumb_720_w = 56, 
                            thumb_80 = '', 
                            thumb_800 = '', 
                            thumb_800_h = 56, 
                            thumb_800_w = 56, 
                            thumb_960 = '', 
                            thumb_960_h = 56, 
                            thumb_960_w = 56, 
                            thumb_tiny = '', 
                            timestamp = 56, 
                            title = '', 
                            updated = 56, 
                            url_private = '', 
                            url_private_download = '', 
                            user = '', 
                            user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            username = '', )
                        ], 
                    icons = slack_beta_ti.models.icons.icons(), 
                    inviter = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    is_delayed_message = True, 
                    is_intro = True, 
                    is_starred = True, 
                    last_read = '0480728880.015280', 
                    latest_reply = '0480728880.015280', 
                    name = '', 
                    old_name = '', 
                    parent_user_id = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    permalink = '', 
                    pinned_to = [
                        'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                        ], 
                    purpose = '', 
                    reactions = [
                        slack_beta_ti.models.reaction_object.Reaction object(
                            count = 56, 
                            name = '', 
                            users = [
                                'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                ], )
                        ], 
                    reply_count = 56, 
                    reply_users = [
                        'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                        ], 
                    reply_users_count = 56, 
                    source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    subscribed = True, 
                    subtype = '', 
                    team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    text = '', 
                    thread_ts = '0480728880.015280', 
                    topic = '', 
                    ts = '0480728880.015280', 
                    type = '', 
                    unread_count = 56, 
                    upload = True, 
                    user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    user_profile = slack_beta_ti.models.objs_user_profile_short.objs_user_profile_short(
                        avatar_hash = '', 
                        display_name = '', 
                        display_name_normalized = '', 
                        image_72 = '', 
                        is_restricted = True, 
                        is_ultra_restricted = True, 
                        name = '', 
                        real_name = '', 
                        real_name_normalized = '', 
                        team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', ), 
                    user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    username = '', ),
                ok = True,
                ts = '0480728880.015280'
            )
        else:
            return ChatPostMessageSuccessSchema(
                channel = 'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                message = slack_beta_ti.models.message_object.Message object(
                    attachments = [
                        None
                        ], 
                    blocks = [
                        None
                        ], 
                    bot_id = slack_beta_ti.models.bot_id.bot_id(), 
                    bot_profile = slack_beta_ti.models.bot_profile_object.Bot Profile Object(
                        app_id = 'A8', 
                        deleted = True, 
                        icons = slack_beta_ti.models.icons.icons(), 
                        id = 'B8Q6ZGCKEC0L3O4GI7XH', 
                        name = '', 
                        team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        updated = 56, ), 
                    client_msg_id = '', 
                    comment = slack_beta_ti.models.file_comment_object.File Comment Object(
                        comment = '', 
                        created = 56, 
                        id = 'Fc8Q6ZGCKEC0L3O4GI7XH', 
                        is_intro = True, 
                        is_starred = True, 
                        num_stars = 56, 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pinned_to = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        reactions = [
                            slack_beta_ti.models.reaction_object.Reaction object(
                                count = 56, 
                                name = '', 
                                users = [
                                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                    ], )
                            ], 
                        timestamp = 56, 
                        user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', ), 
                    display_as_bot = True, 
                    file = slack_beta_ti.models.file_object.file object(
                        channels = [
                            'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        comments_count = 56, 
                        created = 56, 
                        date_delete = 56, 
                        display_as_bot = True, 
                        editable = True, 
                        editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        external_id = '', 
                        external_type = '', 
                        external_url = '', 
                        filetype = '', 
                        groups = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        has_rich_preview = True, 
                        id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                        image_exif_rotation = 56, 
                        ims = [
                            'DQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        is_external = True, 
                        is_public = True, 
                        is_starred = True, 
                        is_tombstoned = True, 
                        last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        mimetype = '', 
                        mode = '', 
                        name = '', 
                        non_owner_editable = True, 
                        num_stars = 56, 
                        original_h = 56, 
                        original_w = 56, 
                        permalink = '', 
                        permalink_public = '', 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pretty_type = '', 
                        preview = '', 
                        public_url_shared = True, 
                        shares = slack_beta_ti.models.shares.shares(), 
                        size = 56, 
                        source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        state = '', 
                        thumb_1024 = '', 
                        thumb_1024_h = 56, 
                        thumb_1024_w = 56, 
                        thumb_160 = '', 
                        thumb_360 = '', 
                        thumb_360_h = 56, 
                        thumb_360_w = 56, 
                        thumb_480 = '', 
                        thumb_480_h = 56, 
                        thumb_480_w = 56, 
                        thumb_64 = '', 
                        thumb_720 = '', 
                        thumb_720_h = 56, 
                        thumb_720_w = 56, 
                        thumb_80 = '', 
                        thumb_800 = '', 
                        thumb_800_h = 56, 
                        thumb_800_w = 56, 
                        thumb_960 = '', 
                        thumb_960_h = 56, 
                        thumb_960_w = 56, 
                        thumb_tiny = '', 
                        timestamp = 56, 
                        title = '', 
                        updated = 56, 
                        url_private = '', 
                        url_private_download = '', 
                        user = '', 
                        user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        username = '', ), 
                    files = [
                        slack_beta_ti.models.file_object.file object(
                            comments_count = 56, 
                            created = 56, 
                            date_delete = 56, 
                            display_as_bot = True, 
                            editable = True, 
                            editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            external_id = '', 
                            external_type = '', 
                            external_url = '', 
                            filetype = '', 
                            has_rich_preview = True, 
                            id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                            image_exif_rotation = 56, 
                            is_external = True, 
                            is_public = True, 
                            is_starred = True, 
                            is_tombstoned = True, 
                            last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            mimetype = '', 
                            mode = '', 
                            name = '', 
                            non_owner_editable = True, 
                            num_stars = 56, 
                            original_h = 56, 
                            original_w = 56, 
                            permalink = '', 
                            permalink_public = '', 
                            pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                            pretty_type = '', 
                            preview = '', 
                            public_url_shared = True, 
                            shares = slack_beta_ti.models.shares.shares(), 
                            size = 56, 
                            source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            state = '', 
                            thumb_1024 = '', 
                            thumb_1024_h = 56, 
                            thumb_1024_w = 56, 
                            thumb_160 = '', 
                            thumb_360 = '', 
                            thumb_360_h = 56, 
                            thumb_360_w = 56, 
                            thumb_480 = '', 
                            thumb_480_h = 56, 
                            thumb_480_w = 56, 
                            thumb_64 = '', 
                            thumb_720 = '', 
                            thumb_720_h = 56, 
                            thumb_720_w = 56, 
                            thumb_80 = '', 
                            thumb_800 = '', 
                            thumb_800_h = 56, 
                            thumb_800_w = 56, 
                            thumb_960 = '', 
                            thumb_960_h = 56, 
                            thumb_960_w = 56, 
                            thumb_tiny = '', 
                            timestamp = 56, 
                            title = '', 
                            updated = 56, 
                            url_private = '', 
                            url_private_download = '', 
                            user = '', 
                            user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            username = '', )
                        ], 
                    icons = slack_beta_ti.models.icons.icons(), 
                    inviter = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    is_delayed_message = True, 
                    is_intro = True, 
                    is_starred = True, 
                    last_read = '0480728880.015280', 
                    latest_reply = '0480728880.015280', 
                    name = '', 
                    old_name = '', 
                    parent_user_id = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    permalink = '', 
                    pinned_to = [
                        'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                        ], 
                    purpose = '', 
                    reactions = [
                        slack_beta_ti.models.reaction_object.Reaction object(
                            count = 56, 
                            name = '', 
                            users = [
                                'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                ], )
                        ], 
                    reply_count = 56, 
                    reply_users = [
                        'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                        ], 
                    reply_users_count = 56, 
                    source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    subscribed = True, 
                    subtype = '', 
                    team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    text = '', 
                    thread_ts = '0480728880.015280', 
                    topic = '', 
                    ts = '0480728880.015280', 
                    type = '', 
                    unread_count = 56, 
                    upload = True, 
                    user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    user_profile = slack_beta_ti.models.objs_user_profile_short.objs_user_profile_short(
                        avatar_hash = '', 
                        display_name = '', 
                        display_name_normalized = '', 
                        image_72 = '', 
                        is_restricted = True, 
                        is_ultra_restricted = True, 
                        name = '', 
                        real_name = '', 
                        real_name_normalized = '', 
                        team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', ), 
                    user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    username = '', ),
                ok = True,
                ts = '0480728880.015280',
        )
        """

    def testChatPostMessageSuccessSchema(self):
        """Test ChatPostMessageSuccessSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_users_conversations(self) -> None:
        """Test case for users_conversations

        """
        pass

    def test_users_delete_photo(self) -> None:
        """Test case for users_delete_photo

        """
        pass

    def test_users_get_presence(self) -> None:
        """Test case for users_get_presence

        """
        pass

    def test_users_identity(self) -> None:
        """Test case for users_identity

        """
        pass

    def test_users_info(self) -> None:
        """Test case for users_info

        """
        pass

    def test_users_list(self) -> None:
        """Test case for users_list

        """
        pass

    def test_users_lookup_by_email(self) -> None:
        """Test case for users_lookup_by_email

        """
        pass

    def test_users_profile_get(self) -> None:
        """Test case for users_profile_get

        """
        pass

    def test_users_profile_set(self) -> None:
        """Test case for users_profile_set

        """
        pass

    def test_users_set_active(self) -> None:
        """Test case for users_set_active

        """
        pass

    def test_users_set_photo(self) -> None:
        """Test case for users_set_photo

        """
        pass

    def test_users_set_presence(self) -> None:
        """Test case for users_set_presence

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import Optional
from typing_extensions import Annotated
from slack_beta_ti.models.usergroups_create_schema import UsergroupsCreateSchema
from slack_beta_ti.models.usergroups_disable_schema import UsergroupsDisableSchema
from slack_beta_ti.models.usergroups_enable_schema import UsergroupsEnableSchema
from slack_beta_ti.models.usergroups_list_schema import UsergroupsListSchema
from slack_beta_ti.models.usergroups_update_schema import UsergroupsUpdateSchema
from slack_beta_ti.models.usergroups_users_list_schema import UsergroupsUsersListSchema
from slack_beta_ti.models.usergroups_users_update_schema import UsergroupsUsersUpdateSchema

from slack_beta_ti.api_client import ApiClient, RequestSerialized
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.rest import RESTResponseType


class UsergroupsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def usergroups_create(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        name: Annotated[StrictStr, Field(description="A name for the User Group. Must be unique among User Groups.")],
        channels: Annotated[Optional[StrictStr], Field(description="A comma separated string of encoded channel IDs for which the User Group uses as a default.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A short description of the User Group.")] = None,
        handle: Annotated[Optional[StrictStr], Field(description="A mention handle. Must be unique among channels, users and User Groups.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in each User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsergroupsCreateSchema:
        """usergroups_create

        Create a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param name: A name for the User Group. Must be unique among User Groups. (required)
        :type name: str
        :param channels: A comma separated string of encoded channel IDs for which the User Group uses as a default.
        :type channels: str
        :param description: A short description of the User Group.
        :type description: str
        :param handle: A mention handle. Must be unique among channels, users and User Groups.
        :type handle: str
        :param include_count: Include the number of users in each User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_create_serialize(
            token=token,
            name=name,
            channels=channels,
            description=description,
            handle=handle,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsCreateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def usergroups_create_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        name: Annotated[StrictStr, Field(description="A name for the User Group. Must be unique among User Groups.")],
        channels: Annotated[Optional[StrictStr], Field(description="A comma separated string of encoded channel IDs for which the User Group uses as a default.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A short description of the User Group.")] = None,
        handle: Annotated[Optional[StrictStr], Field(description="A mention handle. Must be unique among channels, users and User Groups.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in each User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsergroupsCreateSchema]:
        """usergroups_create

        Create a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param name: A name for the User Group. Must be unique among User Groups. (required)
        :type name: str
        :param channels: A comma separated string of encoded channel IDs for which the User Group uses as a default.
        :type channels: str
        :param description: A short description of the User Group.
        :type description: str
        :param handle: A mention handle. Must be unique among channels, users and User Groups.
        :type handle: str
        :param include_count: Include the number of users in each User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_create_serialize(
            token=token,
            name=name,
            channels=channels,
            description=description,
            handle=handle,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsCreateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def usergroups_create_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        name: Annotated[StrictStr, Field(description="A name for the User Group. Must be unique among User Groups.")],
        channels: Annotated[Optional[StrictStr], Field(description="A comma separated string of encoded channel IDs for which the User Group uses as a default.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A short description of the User Group.")] = None,
        handle: Annotated[Optional[StrictStr], Field(description="A mention handle. Must be unique among channels, users and User Groups.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in each User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """usergroups_create

        Create a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param name: A name for the User Group. Must be unique among User Groups. (required)
        :type name: str
        :param channels: A comma separated string of encoded channel IDs for which the User Group uses as a default.
        :type channels: str
        :param description: A short description of the User Group.
        :type description: str
        :param handle: A mention handle. Must be unique among channels, users and User Groups.
        :type handle: str
        :param include_count: Include the number of users in each User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_create_serialize(
            token=token,
            name=name,
            channels=channels,
            description=description,
            handle=handle,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsCreateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _usergroups_create_serialize(
        self,
        token,
        name,
        channels,
        description,
        handle,
        include_count,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channels is not None:
            _form_params.append(('channels', channels))
        if description is not None:
            _form_params.append(('description', description))
        if handle is not None:
            _form_params.append(('handle', handle))
        if include_count is not None:
            _form_params.append(('include_count', include_count))
        if name is not None:
            _form_params.append(('name', name))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/usergroups.create',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def usergroups_disable(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to disable.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsergroupsDisableSchema:
        """usergroups_disable

        Disable an existing User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to disable. (required)
        :type usergroup: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_disable_serialize(
            token=token,
            usergroup=usergroup,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsDisableSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def usergroups_disable_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to disable.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsergroupsDisableSchema]:
        """usergroups_disable

        Disable an existing User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to disable. (required)
        :type usergroup: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_disable_serialize(
            token=token,
            usergroup=usergroup,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsDisableSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def usergroups_disable_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to disable.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """usergroups_disable

        Disable an existing User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to disable. (required)
        :type usergroup: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_disable_serialize(
            token=token,
            usergroup=usergroup,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsDisableSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _usergroups_disable_serialize(
        self,
        token,
        usergroup,
        include_count,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if include_count is not None:
            _form_params.append(('include_count', include_count))
        if usergroup is not None:
            _form_params.append(('usergroup', usergroup))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/usergroups.disable',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def usergroups_enable(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to enable.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsergroupsEnableSchema:
        """usergroups_enable

        Enable a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to enable. (required)
        :type usergroup: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_enable_serialize(
            token=token,
            usergroup=usergroup,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsEnableSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def usergroups_enable_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to enable.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsergroupsEnableSchema]:
        """usergroups_enable

        Enable a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to enable. (required)
        :type usergroup: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_enable_serialize(
            token=token,
            usergroup=usergroup,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsEnableSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def usergroups_enable_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to enable.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """usergroups_enable

        Enable a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to enable. (required)
        :type usergroup: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_enable_serialize(
            token=token,
            usergroup=usergroup,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsEnableSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _usergroups_enable_serialize(
        self,
        token,
        usergroup,
        include_count,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if include_count is not None:
            _form_params.append(('include_count', include_count))
        if usergroup is not None:
            _form_params.append(('usergroup', usergroup))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/usergroups.enable',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def usergroups_list(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:read`")],
        include_users: Annotated[Optional[StrictBool], Field(description="Include the list of users for each User Group.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in each User Group.")] = None,
        include_disabled: Annotated[Optional[StrictBool], Field(description="Include disabled User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsergroupsListSchema:
        """usergroups_list

        List all User Groups for a team

        :param token: Authentication token. Requires scope: `usergroups:read` (required)
        :type token: str
        :param include_users: Include the list of users for each User Group.
        :type include_users: bool
        :param include_count: Include the number of users in each User Group.
        :type include_count: bool
        :param include_disabled: Include disabled User Groups.
        :type include_disabled: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_list_serialize(
            token=token,
            include_users=include_users,
            include_count=include_count,
            include_disabled=include_disabled,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def usergroups_list_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:read`")],
        include_users: Annotated[Optional[StrictBool], Field(description="Include the list of users for each User Group.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in each User Group.")] = None,
        include_disabled: Annotated[Optional[StrictBool], Field(description="Include disabled User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsergroupsListSchema]:
        """usergroups_list

        List all User Groups for a team

        :param token: Authentication token. Requires scope: `usergroups:read` (required)
        :type token: str
        :param include_users: Include the list of users for each User Group.
        :type include_users: bool
        :param include_count: Include the number of users in each User Group.
        :type include_count: bool
        :param include_disabled: Include disabled User Groups.
        :type include_disabled: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_list_serialize(
            token=token,
            include_users=include_users,
            include_count=include_count,
            include_disabled=include_disabled,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def usergroups_list_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:read`")],
        include_users: Annotated[Optional[StrictBool], Field(description="Include the list of users for each User Group.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in each User Group.")] = None,
        include_disabled: Annotated[Optional[StrictBool], Field(description="Include disabled User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """usergroups_list

        List all User Groups for a team

        :param token: Authentication token. Requires scope: `usergroups:read` (required)
        :type token: str
        :param include_users: Include the list of users for each User Group.
        :type include_users: bool
        :param include_count: Include the number of users in each User Group.
        :type include_count: bool
        :param include_disabled: Include disabled User Groups.
        :type include_disabled: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_list_serialize(
            token=token,
            include_users=include_users,
            include_count=include_count,
            include_disabled=include_disabled,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _usergroups_list_serialize(
        self,
        token,
        include_users,
        include_count,
        include_disabled,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if include_users is not None:
            
            _query_params.append(('include_users', include_users))
            
        if token is not None:
            
            _query_params.append(('token', token))
            
        if include_count is not None:
            
            _query_params.append(('include_count', include_count))
            
        if include_disabled is not None:
            
            _query_params.append(('include_disabled', include_disabled))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/usergroups.list',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def usergroups_update(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        handle: Annotated[Optional[StrictStr], Field(description="A mention handle. Must be unique among channels, users and User Groups.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A short description of the User Group.")] = None,
        channels: Annotated[Optional[StrictStr], Field(description="A comma separated string of encoded channel IDs for which the User Group uses as a default.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        name: Annotated[Optional[StrictStr], Field(description="A name for the User Group. Must be unique among User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsergroupsUpdateSchema:
        """usergroups_update

        Update an existing User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param handle: A mention handle. Must be unique among channels, users and User Groups.
        :type handle: str
        :param description: A short description of the User Group.
        :type description: str
        :param channels: A comma separated string of encoded channel IDs for which the User Group uses as a default.
        :type channels: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :param name: A name for the User Group. Must be unique among User Groups.
        :type name: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_update_serialize(
            token=token,
            usergroup=usergroup,
            handle=handle,
            description=description,
            channels=channels,
            include_count=include_count,
            name=name,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUpdateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def usergroups_update_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        handle: Annotated[Optional[StrictStr], Field(description="A mention handle. Must be unique among channels, users and User Groups.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A short description of the User Group.")] = None,
        channels: Annotated[Optional[StrictStr], Field(description="A comma separated string of encoded channel IDs for which the User Group uses as a default.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        name: Annotated[Optional[StrictStr], Field(description="A name for the User Group. Must be unique among User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsergroupsUpdateSchema]:
        """usergroups_update

        Update an existing User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param handle: A mention handle. Must be unique among channels, users and User Groups.
        :type handle: str
        :param description: A short description of the User Group.
        :type description: str
        :param channels: A comma separated string of encoded channel IDs for which the User Group uses as a default.
        :type channels: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :param name: A name for the User Group. Must be unique among User Groups.
        :type name: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_update_serialize(
            token=token,
            usergroup=usergroup,
            handle=handle,
            description=description,
            channels=channels,
            include_count=include_count,
            name=name,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUpdateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def usergroups_update_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        handle: Annotated[Optional[StrictStr], Field(description="A mention handle. Must be unique among channels, users and User Groups.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A short description of the User Group.")] = None,
        channels: Annotated[Optional[StrictStr], Field(description="A comma separated string of encoded channel IDs for which the User Group uses as a default.")] = None,
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        name: Annotated[Optional[StrictStr], Field(description="A name for the User Group. Must be unique among User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """usergroups_update

        Update an existing User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param handle: A mention handle. Must be unique among channels, users and User Groups.
        :type handle: str
        :param description: A short description of the User Group.
        :type description: str
        :param channels: A comma separated string of encoded channel IDs for which the User Group uses as a default.
        :type channels: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :param name: A name for the User Group. Must be unique among User Groups.
        :type name: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_update_serialize(
            token=token,
            usergroup=usergroup,
            handle=handle,
            description=description,
            channels=channels,
            include_count=include_count,
            name=name,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUpdateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _usergroups_update_serialize(
        self,
        token,
        usergroup,
        handle,
        description,
        channels,
        include_count,
        name,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if handle is not None:
            _form_params.append(('handle', handle))
        if description is not None:
            _form_params.append(('description', description))
        if channels is not None:
            _form_params.append(('channels', channels))
        if include_count is not None:
            _form_params.append(('include_count', include_count))
        if usergroup is not None:
            _form_params.append(('usergroup', usergroup))
        if name is not None:
            _form_params.append(('name', name))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/usergroups.update',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def usergroups_users_list(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:read`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        include_disabled: Annotated[Optional[StrictBool], Field(description="Allow results that involve disabled User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsergroupsUsersListSchema:
        """usergroups_users_list

        List all users in a User Group

        :param token: Authentication token. Requires scope: `usergroups:read` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param include_disabled: Allow results that involve disabled User Groups.
        :type include_disabled: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_users_list_serialize(
            token=token,
            usergroup=usergroup,
            include_disabled=include_disabled,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUsersListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def usergroups_users_list_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:read`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        include_disabled: Annotated[Optional[StrictBool], Field(description="Allow results that involve disabled User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsergroupsUsersListSchema]:
        """usergroups_users_list

        List all users in a User Group

        :param token: Authentication token. Requires scope: `usergroups:read` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param include_disabled: Allow results that involve disabled User Groups.
        :type include_disabled: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_users_list_serialize(
            token=token,
            usergroup=usergroup,
            include_disabled=include_disabled,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUsersListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def usergroups_users_list_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:read`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        include_disabled: Annotated[Optional[StrictBool], Field(description="Allow results that involve disabled User Groups.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """usergroups_users_list

        List all users in a User Group

        :param token: Authentication token. Requires scope: `usergroups:read` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param include_disabled: Allow results that involve disabled User Groups.
        :type include_disabled: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_users_list_serialize(
            token=token,
            usergroup=usergroup,
            include_disabled=include_disabled,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUsersListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _usergroups_users_list_serialize(
        self,
        token,
        usergroup,
        include_disabled,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        if include_disabled is not None:
            
            _query_params.append(('include_disabled', include_disabled))
            
        if usergroup is not None:
            
            _query_params.append(('usergroup', usergroup))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/usergroups.users.list',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def usergroups_users_update(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        users: Annotated[StrictStr, Field(description="A comma separated string of encoded user IDs that represent the entire list of users for the User Group.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsergroupsUsersUpdateSchema:
        """usergroups_users_update

        Update the list of users for a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param users: A comma separated string of encoded user IDs that represent the entire list of users for the User Group. (required)
        :type users: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_users_update_serialize(
            token=token,
            usergroup=usergroup,
            users=users,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUsersUpdateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def usergroups_users_update_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        users: Annotated[StrictStr, Field(description="A comma separated string of encoded user IDs that represent the entire list of users for the User Group.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsergroupsUsersUpdateSchema]:
        """usergroups_users_update

        Update the list of users for a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param users: A comma separated string of encoded user IDs that represent the entire list of users for the User Group. (required)
        :type users: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_users_update_serialize(
            token=token,
            usergroup=usergroup,
            users=users,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUsersUpdateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def usergroups_users_update_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `usergroups:write`")],
        usergroup: Annotated[StrictStr, Field(description="The encoded ID of the User Group to update.")],
        users: Annotated[StrictStr, Field(description="A comma separated string of encoded user IDs that represent the entire list of users for the User Group.")],
        include_count: Annotated[Optional[StrictBool], Field(description="Include the number of users in the User Group.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """usergroups_users_update

        Update the list of users for a User Group

        :param token: Authentication token. Requires scope: `usergroups:write` (required)
        :type token: str
        :param usergroup: The encoded ID of the User Group to update. (required)
        :type usergroup: str
        :param users: A comma separated string of encoded user IDs that represent the entire list of users for the User Group. (required)
        :type users: str
        :param include_count: Include the number of users in the User Group.
        :type include_count: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._usergroups_users_update_serialize(
            token=token,
            usergroup=usergroup,
            users=users,
            include_count=include_count,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsergroupsUsersUpdateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _usergroups_users_update_serialize(
        self,
        token,
        usergroup,
        users,
        include_count,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if include_count is not None:
            _form_params.append(('include_count', include_count))
        if usergroup is not None:
            _form_params.append(('usergroup', usergroup))
        if users is not None:
            _form_params.append(('users', users))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/usergroups.users.update',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )


